@@ -1,8 +1,8 @@
-"""### _Subsurface specific plugins_
-
-These are plugins relevant within subsurface workflows. Most of them
-rely on the setting `scratch_ensemble` configuration within the
-`plugin_settings`.
+"""These are plugins relevant within subsurface workflows. Most of them
+rely on the setting `scratch_ensembles` within
+`shared_settings`. This setting connects ensemble names (user defined)
+with the paths to where the ensembles are stored, either absolute or
+relative to the location of the configuration file.
 I.e. you could have
 ```yaml
 title: Reek Webviz Demonstration
