@@ -22,36 +22,83 @@ from .._abbreviations.reservoir_simulation import (
 from .._utils.simulation_timeseries import (
     set_simulation_line_shape_fallback,
     get_simulation_line_shape,
+    calc_series_statistics,
+    add_fanchart_traces,
 )
+from .._utils.unique_theming import unique_colors
 
 
 class ReservoirSimulationTimeSeries(WebvizPluginABC):
-    """### ReservoirSimulationTimeSeries
+    """Visualizes reservoir simulation time series data for FMU ensembles.
 
-Visualizes reservoir simulation time series for FMU ensembles.
-Input can be given either as aggregated csv file or an ensemble defined
-in plugin settings.
+---
+**Two main options for input data: Aggregated and read from UNSMRY.**
 
-* `csvfile`: Aggregated csvfile for unsmry with 'REAL', 'ENSEMBLE', 'DATE' and vector columns
-* `ensembles`: Which ensembles in `shared_settings` to visualize.
-* `column_keys`: List of vectors to extract. If not given, all vectors
-                 from the simulations will be extracted. Wild card asterisk *
-                 can be used.
-* `sampling`: Time separation between extracted values. Can be e.g. `monthly`
-              or `yearly`.
-* `options`: Options to initialize plots with. See below
-* `line_shape_fallback`: Fallback interpolation method between points. Vectors identified as rates
-                or phase ratios are always backfilled, vectors identified as cumulative (totals)
-                are always linearly interpolated. The rest use the fallback.
-                Supported: `linear` (default), `backfilled` + regular Plotly options: `hv`, `vh`,
-                `hvh`, `vhv` and `spline`.
+**Using aggregated data**
+* **`csvfile`:** Aggregated csv file with `REAL`, `ENSEMBLE`, \
+    `DATE` and vector columns.
 
-Plot options:
+**Using simulation time series data directly from `UNSMRY` files**
+* **`ensembles`:** Which ensembles in `shared_settings` to visualize.
+* **`column_keys`:** List of vectors to extract. If not given, all vectors \
+    from the simulations will be extracted. Wild card asterisk `*` can be used.
+* **`sampling`:** Time separation between extracted values. Can be e.g. `monthly` (default) or \
+    `yearly`.
+
+**Common optional settings for both input options**
+* **`obsfile`**: File with observations to plot together with the relevant time series. \
+(absolute path or relative to config file).
+* **`options`:** Options to initialize plots with:
     * `vector1` : First vector to display
     * `vector2` : Second vector to display
     * `vector3` : Third vector to display
-    * `visualization` : 'realizations', 'statistics' or 'statistics_hist',
+    * `visualization` : `realizations`, `statistics` or `statistics_hist`
     * `date` : Date to show in histograms
+* **`line_shape_fallback`:** Fallback interpolation method between points. Vectors identified as \
+    rates or phase ratios are always backfilled, vectors identified as cumulative (totals) are \
+    always linearly interpolated. The rest use the fallback.
+    Supported options:
+    * `linear` (default)
+    * `backfilled`
+    * `hv`, `vh`, `hvh`, `vhv` and `spline` (regular Plotly options).
+
+---
+
+?> Vectors that are identified as historical vectors (e.g. FOPTH is the history of FOPT) will \
+be plotted together with their non-historical counterparts as reference lines, and they are \
+therefore not selectable as vectors to plot initially.
+
+?> The `obsfile` is a common (optional) file for all ensembles, which currently has to be made \
+manually. [An example of the format can be found here]\
+(https://github.com/equinor/webviz-subsurface-testdata/blob/master/\
+reek_history_match/share/observations/observations.yml).
+
+!> It is **strongly recommended** to keep the data frequency to a regular frequency (like \
+`monthly` or `yearly`). This applies to both csv input and when reading from `UNSMRY` \
+(controlled by the `sampling` key). This is because the statistics and fancharts are calculated \
+per DATE over all realizations in an ensemble, and the available dates should therefore not \
+differ between individual realizations of an ensemble.
+
+**Using aggregated data**
+
+The `csvfile` must have columns `ENSEMBLE`, `REAL` and `DATE` in addition to the individual
+vectors.
+* [Example of aggregated file]\
+(https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_data/smry.csv).
+
+**Using simulation time series data directly from `.UNSMRY` files**
+
+Vectors are extracted automatically from the `UNSMRY` files in the individual realizations,
+using the `fmu-ensemble` library.
+
+?> Using the `UNSMRY` method will also extract metadata like units, and whether the vector is a \
+rate, a cumulative, or historical. Units are e.g. added to the plot titles, while rates and \
+cumulatives are used to decide the line shapes in the plot. Aggregated data may on the other \
+speed up the build of the app, as processing of `UNSMRY` files can be slow for large models.
+
+!> The `UNSMRY` files are auto-detected by `fmu-ensemble` in the `eclipse/model` folder of the \
+individual realizations. You should therefore not have more than one `UNSMRY` file in this \
+folder, to avoid risk of not extracting the right data.
 """
 
     ENSEMBLE_COLUMNS = ["REAL", "ENSEMBLE", "DATE"]
@@ -151,33 +198,7 @@ Plot options:
 
     @property
     def ens_colors(self):
-        try:
-            colors = self.theme.plotly_theme["layout"]["colorway"]
-        except KeyError:
-            colors = self.theme.plotly_theme.get(
-                "colorway",
-                [
-                    "#243746",
-                    "#eb0036",
-                    "#919ba2",
-                    "#7d0023",
-                    "#66737d",
-                    "#4c9ba1",
-                    "#a44c65",
-                    "#80b7bc",
-                    "#ff1243",
-                    "#919ba2",
-                    "#be8091",
-                    "#b2d4d7",
-                    "#ff597b",
-                    "#bdc3c7",
-                    "#d8b2bd",
-                    "#ffe7d6",
-                    "#d5eaf4",
-                    "#ff88a1",
-                ],
-            )
-        return {ens: colors[self.ensembles.index(ens)] for ens in self.ensembles}
+        return unique_colors(self.ensembles, self.theme)
 
     @property
     def tour_steps(self):
@@ -492,6 +513,19 @@ Plot options:
                 subplot_titles=titles,
             )
 
+            if calc_mode == "ensembles":
+                data = filter_df(self.smry, ensembles, vectors, self.smry_meta)
+            elif calc_mode == "delta_ensembles":
+                data = filter_df(
+                    self.smry, [base_ens, delta_ens], vectors, self.smry_meta
+                )
+                data = calculate_delta(data, base_ens, delta_ens)
+            else:
+                raise PreventUpdate
+
+            if visualization in ["statistics", "statistics_hist"]:
+                stat_df = calc_series_statistics(data, vectors)
+
             # Loop through each vector and calculate relevant plot
             legends = []
             for i, vector in enumerate(vectors):
@@ -500,47 +534,35 @@ Plot options:
                     vector=vector,
                     smry_meta=self.smry_meta,
                 )
-                if calc_mode == "ensembles":
-                    data = filter_df(self.smry, ensembles, vector, self.smry_meta)
-                elif calc_mode == "delta_ensembles":
-                    data = filter_df(
-                        self.smry, [base_ens, delta_ens], vector, self.smry_meta
+
+                if visualization in ["statistics", "statistics_hist"]:
+                    traces = add_statistic_traces(
+                        stat_df, vector, colors=self.ens_colors, line_shape=line_shape,
+                    )
+                    if visualization == "statistics_hist":
+                        histdata = add_histogram_traces(
+                            data, vector, date=date, colors=self.ens_colors
+                        )
+                        for trace in histdata:
+                            fig.add_trace(trace, i + 1, 2)
+                elif visualization == "realizations":
+                    traces = add_realization_traces(
+                        data, vector, colors=self.ens_colors, line_shape=line_shape,
                     )
-                    data = calculate_delta(data, base_ens, delta_ens)
                 else:
                     raise PreventUpdate
 
-                if visualization == "statistics":
-                    traces = add_statistic_traces(
-                        data,
-                        vector,
-                        colors=self.ens_colors,
-                        line_shape=line_shape,
-                        smry_meta=self.smry_meta,
+                if (
+                    historical_vector(vector=vector, smry_meta=self.smry_meta)
+                    in data.columns
+                ):
+                    traces.append(
+                        add_history_trace(
+                            data,
+                            historical_vector(vector=vector, smry_meta=self.smry_meta),
+                            line_shape,
+                        )
                     )
-                elif visualization == "realizations":
-                    traces = add_realization_traces(
-                        data,
-                        vector,
-                        colors=self.ens_colors,
-                        line_shape=line_shape,
-                        smry_meta=self.smry_meta,
-                    )
-                elif visualization == "statistics_hist":
-                    traces = add_statistic_traces(
-                        data,
-                        vector,
-                        colors=self.ens_colors,
-                        line_shape=line_shape,
-                        smry_meta=self.smry_meta,
-                    )
-                    histdata = add_histogram_traces(
-                        data, vector, date=date, colors=self.ens_colors
-                    )
-                    for trace in histdata:
-                        fig.add_trace(trace, i + 1, 2)
-                else:
-                    raise PreventUpdate
 
                 # Remove unwanted legends(only keep one for each ensemble)
                 for trace in traces:
@@ -578,6 +600,80 @@ Plot options:
                     fig["layout"]["xaxis6"]["showticklabels"] = True
             return fig
 
+        @app.callback(
+            self.plugin_data_output,
+            [self.plugin_data_requested],
+            [
+                State(self.uuid("vector1"), "value"),
+                State(self.uuid("vector2"), "value"),
+                State(self.uuid("vector3"), "value"),
+                State(self.uuid("ensemble"), "value"),
+                State(self.uuid("mode"), "value"),
+                State(self.uuid("base_ens"), "value"),
+                State(self.uuid("delta_ens"), "value"),
+                State(self.uuid("statistics"), "value"),
+            ],
+        )
+        def _user_download_data(
+            data_requested,
+            vector1,
+            vector2,
+            vector3,
+            ensembles,
+            calc_mode,
+            base_ens,
+            delta_ens,
+            visualization,
+        ):
+            """Callback to download data based on selections"""
+
+            # Combine selected vectors
+            vectors = [vector1]
+            if vector2:
+                vectors.append(vector2)
+            if vector3:
+                vectors.append(vector3)
+
+            if calc_mode == "ensembles":
+                # Ensure selected ensembles is a list
+                ensembles = ensembles if isinstance(ensembles, list) else [ensembles]
+                data = filter_df(self.smry, ensembles, vectors, self.smry_meta)
+            elif calc_mode == "delta_ensembles":
+                data = filter_df(
+                    self.smry, [base_ens, delta_ens], vectors, self.smry_meta
+                )
+                data = calculate_delta(data, base_ens, delta_ens)
+            else:
+                raise PreventUpdate
+
+            if visualization in ["statistics", "statistics_hist"]:
+                data = calc_series_statistics(data, vectors)
+                data = data.sort_values(by=[("", "ENSEMBLE"), ("", "DATE")])
+            else:
+                data = data.sort_values(by=["ENSEMBLE", "REAL", "DATE"])
+                # Reorder columns
+                data = data[
+                    ["ENSEMBLE", "REAL", "DATE"]
+                    + [
+                        col
+                        for col in data.columns
+                        if col not in ["ENSEMBLE", "REAL", "DATE"]
+                    ]
+                ]
+
+            return (
+                WebvizPluginABC.plugin_data_compress(
+                    [
+                        {
+                            "filename": "reservoir_simulation_timeseries.csv",
+                            "content": data.to_csv(index=False),
+                        }
+                    ]
+                )
+                if data_requested
+                else ""
+            )
+
         @app.callback(
             [
                 Output(self.uuid("show_ensembles"), "style"),
@@ -646,12 +742,13 @@ def format_observations(obslist):
 
 
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
-def filter_df(df, ensembles, vector, smry_meta):
+def filter_df(df, ensembles, vectors, smry_meta):
     """Filter dataframe for current vector. Include history
     vector if present"""
-    columns = ["REAL", "ENSEMBLE", vector, "DATE"]
-    if historical_vector(vector=vector, smry_meta=smry_meta) in df.columns:
-        columns.append(historical_vector(vector=vector, smry_meta=smry_meta))
+    columns = ["REAL", "ENSEMBLE", "DATE"] + vectors
+    for vector in vectors:
+        if historical_vector(vector=vector, smry_meta=smry_meta) in df.columns:
+            columns.append(historical_vector(vector=vector, smry_meta=smry_meta))
 
     return df.loc[df["ENSEMBLE"].isin(ensembles)][columns]
 
@@ -716,9 +813,9 @@ def add_observation_trace(obs):
 
 
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
-def add_realization_traces(dframe, vector, colors, line_shape, smry_meta):
+def add_realization_traces(dframe, vector, colors, line_shape):
     """Renders line trace for each realization, includes history line if present"""
-    traces = [
+    return [
         {
             "line": {"shape": line_shape},
             "x": list(real_df["DATE"]),
@@ -733,16 +830,6 @@ def add_realization_traces(dframe, vector, colors, line_shape, smry_meta):
         for real_no, (real, real_df) in enumerate(ens_df.groupby("REAL"))
     ]
 
-    if historical_vector(vector=vector, smry_meta=smry_meta) in dframe.columns:
-        traces.append(
-            add_history_trace(
-                dframe,
-                historical_vector(vector=vector, smry_meta=smry_meta),
-                line_shape,
-            )
-        )
-    return traces
-
 
 def add_history_trace(dframe, vector, line_shape):
     """Renders the history line"""
@@ -763,115 +850,22 @@ def add_history_trace(dframe, vector, line_shape):
 
 
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
-def add_statistic_traces(df, vector, colors, line_shape, smry_meta):
-    """Calculate statistics for a given vector for relevant ensembles"""
-    quantiles = [10, 90]
+def add_statistic_traces(stat_df, vector, colors, line_shape):
+    """Add fanchart traces for selected vector"""
     traces = []
-
-    for ensemble, ens_df in df.groupby("ENSEMBLE"):
-        dframe = ens_df.drop(columns=["ENSEMBLE", "REAL"]).groupby("DATE")
-
-        # Build a dictionary of dataframes to be concatenated
-        dframes = {}
-        dframes["mean"] = dframe.mean()
-        for quantile in quantiles:
-            quantile_str = "p" + str(quantile)
-            dframes[quantile_str] = dframe.quantile(q=quantile / 100.0)
-        dframes["maximum"] = dframe.max()
-        dframes["minimum"] = dframe.min()
+    for ensemble, ens_df in stat_df.groupby(("", "ENSEMBLE")):
         traces.extend(
             add_fanchart_traces(
-                pd.concat(dframes, names=["STATISTIC"], sort=False)[vector],
+                ens_df,
+                vector,
                 colors.get(ensemble, colors[list(colors.keys())[0]]),
                 ensemble,
                 line_shape,
             )
         )
-    if historical_vector(vector=vector, smry_meta=smry_meta) in df.columns:
-        traces.append(
-            add_history_trace(
-                df, historical_vector(vector=vector, smry_meta=smry_meta), line_shape,
-            )
-        )
     return traces
 
 
-def add_fanchart_traces(vector_stats, color, legend_group: str, line_shape):
-    """Renders a fanchart for an ensemble vector"""
-
-    fill_color = hex_to_rgb(color, 0.3)
-    line_color = hex_to_rgb(color, 1)
-    return [
-        {
-            "name": legend_group,
-            "hovertext": "Maximum",
-            "x": vector_stats["maximum"].index.tolist(),
-            "y": vector_stats["maximum"].values,
-            "mode": "lines",
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "P10",
-            "x": vector_stats["p10"].index.tolist(),
-            "y": vector_stats["p10"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "Mean",
-            "x": vector_stats["mean"].index.tolist(),
-            "y": vector_stats["mean"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": True,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "P90",
-            "x": vector_stats["p90"].index.tolist(),
-            "y": vector_stats["p90"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "Minimum",
-            "x": vector_stats["minimum"].index.tolist(),
-            "y": vector_stats["minimum"].values,
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-    ]
-
-
-def hex_to_rgb(hex_string, opacity=1):
-    """Converts a hex color to rgb"""
-    hex_string = hex_string.lstrip("#")
-    hlen = len(hex_string)
-    rgb = [int(hex_string[i : i + hlen // 3], 16) for i in range(0, hlen, hlen // 3)]
-    rgb.append(opacity)
-    return f"rgba{tuple(rgb)}"
-
-
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
 @webvizstore
 def read_csv(csv_file) -> pd.DataFrame:
