@@ -35,44 +35,72 @@ from .._utils.simulation_timeseries import (
 
 # pylint: disable=too-many-instance-attributes
 class ReservoirSimulationTimeSeriesOneByOne(WebvizPluginABC):
-    """### ReservoirSimulationTimeSeriesOneByOne
+    """Visualizes reservoir simulation time series data for sensitivity studies based \
+on a design matrix.
 
-Visualizes reservoir simulation time series for sensitivity studies.
-
-A tornadoplot can be calculated interactively for each date/vector by choosing a data.
+A tornado plot can be calculated interactively for each date/vector by selecting a date.
 After selecting a date individual sensitivities can be selected to highlight the realizations
 run with that sensitivity.
 
-Input can be given either as aggregated csv files for summary vectors and sensitivity
-information, or as an ensemble name defined in 'shared_settings'.
+---
+**Two main options for input data: Aggregated and read from UNSMRY.**
 
-#### Time series input
-The time series input can either extracted automatically from the ensemble or
-provided as a standalone csv.
-[Example file](
-https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_data/smry.csv)
+**Using aggregated data**
+* **`csvfile_smry`:** Aggregated `csv` file for volumes with `REAL`, `ENSEMBLE`, `DATE` and \
+    vector columns (absolute path or relative to config file).
+* **`csvfile_parameters`:** Aggregated `csv` file for sensitivity information with `REAL`, \
+    `ENSEMBLE`, `SENSNAME` and `SENSCASE` columns (absolute path or relative to config file).
+
+**Using simulation time series data directly from `UNSMRY` files**
+* **`ensembles`:** Which ensembles in `shared_settings` to visualize.
+* **`column_keys`:** List of vectors to extract. If not given, all vectors \
+    from the simulations will be extracted. Wild card asterisk `*` can be used.
+* **`sampling`:** Time separation between extracted values. Can be e.g. `monthly` (default) or \
+    `yearly`.
+
+**Common optional settings for both input options**
+* **`initial_vector`:** Initial vector to display
+* **`line_shape_fallback`:** Fallback interpolation method between points. Vectors identified as \
+    rates or phase ratios are always backfilled, vectors identified as cumulative (totals) are \
+    always linearly interpolated. The rest use the fallback.
+    Supported options:
+    * `linear` (default)
+    * `backfilled`
+    * `hv`, `vh`, `hvh`, `vhv` and `spline` (regular Plotly options).
+
+---
+!> It is **strongly recommended** to keep the data frequency to a regular frequency (like \
+`monthly` or `yearly`). This applies to both csv input and when reading from `UNSMRY` \
+(controlled by the `sampling` key). This is because the statistics and fancharts are calculated \
+per DATE over all realizations in an ensemble, and the available dates should therefore not \
+differ between individual realizations of an ensemble.
 
 
-#### Sensitivity input
+**Using aggregated data**
 
-The sensitivity information is extracted automatically if an ensemble is given as input,
-as long as *SENSCASE* and *SENSNAME* is found in *parameters.txt*.[Example csv file](
-https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_data/realdata.csv)
+* [Example of csvfile_smry]\
+(https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_data/smry.csv).
 
-* `csvfile_smry`: Aggregated csvfile for volumes with 'REAL', 'ENSEMBLE', 'DATE' and vector columns
-* `csvfile_parameters`: Aggregated csvfile for sensitivity information
-* `ensembles`: Which ensembles in `shared_settings` to visualize.
-* `column_keys`: List of vectors to extract. If not given, all vectors
-                 from the simulations will be extracted. Wild card asterisk *
-                 can be used.
-* `initial_vector`: Initial vector to display
-* `sampling`: Time separation between extracted values. Can be e.g. `monthly`
-              or `yearly`.
-* `line_shape_fallback`: Fallback interpolation method between points. Vectors identified as rates
-                or phase ratios are always backfilled, vectors identified as cumulative (totals)
-                are always linearly interpolated. The rest use the fallback.
-                Supported: `linear` (default), `backfilled` + regular Plotly options: `hv`, `vh`,
-                `hvh`, `vhv` and `spline`.
+* [Example of csvfile_parameters]\
+(https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_data/parameters.csv).
+
+
+**Using simulation time series data directly from `.UNSMRY` files**
+
+Time series data are extracted automatically from the `UNSMRY` files in the individual
+realizations, using the `fmu-ensemble` library. The `SENSNAME` and `SENSCASE` values are read
+directly from the `parameters.txt` files of the individual realizations, assuming that these
+exist. If the `SENSCASE` of a realization is `p10_p90`, the sensitivity case is regarded as a
+**Monte Carlo** style sensitivity, otherwise the case is evaluated as a **scalar** sensitivity.
+
+?> Using the `UNSMRY` method will also extract metadata like units, and whether the vector is a \
+rate, a cumulative, or historical. Units are e.g. added to the plot titles, while rates and \
+cumulatives are used to decide the line shapes in the plot. Aggregated data may on the other \
+speed up the build of the app, as processing of `UNSMRY` files can be slow for large models.
+
+!> The `UNSMRY` files are auto-detected by `fmu-ensemble` in the `eclipse/model` folder of the \
+individual realizations. You should therefore not have more than one `UNSMRY` file in this \
+folder, to avoid risk of not extracting the right data.
 """
 
     ENSEMBLE_COLUMNS = [
